( cd usr/lib ; rm -rf libburn.so.1 )
( cd usr/lib ; ln -sf libburn.so.1.0.0 libburn.so.1 )
( cd usr/lib ; rm -rf libburn.so )
( cd usr/lib ; ln -sf libburn.so.1.0.0 libburn.so )
( cd usr/lib ; rm -rf libisofs.so.1 )
( cd usr/lib ; ln -sf libisofs.so.1.0.0 libisofs.so.1 )
( cd usr/lib ; rm -rf libisofs.so )
( cd usr/lib ; ln -sf libisofs.so.1.0.0 libisofs.so )
